@@ -6,6 +6,12 @@ test_that("Type of data in the explainer and label",{
   explainer_ranger_1 <- explain(model_classif_ranger, label = "Test", verbose = FALSE)
   explainer_ranger_2 <- explain(model_classif_ranger, data = titanic_imputed, label = "Test 2", verbose = FALSE)
   explainer_lm_1 <- explain(model_regr_lm, verbose = FALSE)
+  data_matrix <- as.matrix(titanic_imputed)
+  rownames(data_matrix) <- NULL
+  explainer_ranger_13 <- explain(model_classif_ranger, data = data_matrix, label = "rownames", verbose = FALSE)
+  colnames(data_matrix) <- NULL
+  explainer_ranger_14 <- explain(model_classif_ranger, data = data_matrix, label = "colnames", verbose = FALSE)
+
 
   expect_is(explainer_ranger_1, "explainer")
   expect_is(explainer_ranger_2, "explainer")
@@ -16,6 +22,8 @@ test_that("Type of data in the explainer and label",{
   expect_null(explainer_ranger_1$data)
   expect_is(explainer_ranger_2$data, "data.frame")
   expect_is(explainer_lm_1$data, "data.frame")
+  expect_false(is.null(rownames(explainer_ranger_13$data)))
+  expect_false(is.null(colnames(explainer_ranger_14$data)))
 })
 
 test_that("Checks for y",{
@@ -71,7 +79,6 @@ test_that("predict and residual functions", {
   expect_is(explainer_ranger_9$y_hat, "factor")
   expect_is(explainer_ranger_10$residuals, "numeric")
   expect_is(explainer_ranger_11$y_hat, "numeric")
-  expect_null(explainer_ranger_12$y_hat)
 
 
 })
